@@ -1,11 +1,40 @@
+import operator as _operator
+from enum import Enum as _Enum
+from typing import Callable as _Callable
+
+from django.db import models as _models
 from django.db.models import enums as _enums
 
 __all__ = [
     "States",
     "Colors",
+    "Operator",
+    "OrderedTextChoices",
 ]
 
 
+class Operator(_Enum):
+    LT = _operator.lt
+    GT = _operator.gt
+    LTE = _operator.le
+    GTE = _operator.ge
+
+
+class OrderedTextChoices(_models.TextChoices):
+    @classmethod
+    def get_value(cls, choice) -> int | None:
+        for index, option in enumerate(cls.choices):
+            if choice == option[0]:
+                return index
+
+    @classmethod
+    def compare(cls, first, op: Operator | _Callable, second) -> bool:
+        if callable(op):
+            return op(cls.get_value(first), cls.get_value(second))
+
+        return op.value(cls.get_value(first), cls.get_value(second))
+
+
 class States(_enums.TextChoices):
     AC = "AC", "Acre"
     AL = "AL", "Alagoas"
